@@ -1190,6 +1190,17 @@ EAPI void elm_win_screen_size_get(const Elm_Win *obj, int *x, int *y, int *w, in
  */
 EAPI Evas_Object *elm_win_main_menu_get(const Elm_Win *obj);
 
+/**
+ * @brief Get the Ecore_Cocoa_Window of an Evas.Object.
+ *
+ * @return The Ecore_Cocoa_Window of @c obj.
+ *
+ * @since 1.17
+ *
+ * @ingroup Elm_Win
+ */
+EAPI Ecore_Cocoa_Window *elm_win_cocoa_window_get(const Elm_Win *obj);
+
 /**
  * @brief Get screen dpi for the screen that a window is on.
  *
